<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// 0
'0_URL' => 'http://listes.rezo.net/mailman/listinfo/spip-es',
'0_langue' => 'espa&ntilde;ol [es]',
'0_liste' => 'spip-es@rezo.net',
'0_mainteneur' => 'spip-dev@rezo.net',

// A
'access_interface_graphique' => 'Volver a la interfaz gr&aacute;fica completa',
'access_mode_texte' => 'Mostrar la interfaz simplificada en modo texto',
'admin_debug' => 'debug',
'admin_modifier_article' => 'Modificar este art&iacute;culo',
'admin_modifier_auteur' => 'Modificar esta autora o autor',
'admin_modifier_breve' => 'Modificar esta breve',
'admin_modifier_mot' => 'Modificar esta palabra clave',
'admin_modifier_rubrique' => 'Modificar esta secci&oacute;n',
'admin_recalculer' => 'Actualizar esta p&aacute;gina',
'afficher_trad' => 'mostrar las traducciones',
'alerte_maj_impossible' => '<<b>&iexcl;Alerta!</b> La actualizaci&oacute;n de la base SQL a la versi&oacute;n @version@ es imposible, quiz&aacute;s por un problema de derechos de modificaci&oacute;n de la base de datos. Por favor, contacta a tu hospedaje.',
'alerte_modif_info_concourante' => 'ATENCI&Oacute;N: Esta informaci&oacute;n fue modificada por otro lado. El valor actual es:',
'analyse_xml' => 'An&aacute;lisis XML',
'annuler' => 'Cancelar',
'antispam_champ_vide' => 'Por favor, deje este campo vac&iacute;o&nbsp;:',
'articles_recents' => 'Los art&iacute;culos m&aacute;s recientes',
'avis_archive_incorrect' => 'El archivo de respaldo no es un archivo SPIP.',
'avis_archive_invalide' => 'el archivo de respaldo no es v&aacute;lido',
'avis_attention' => '&iexcl;ATENCI&Oacute;N!',
'avis_champ_incorrect_type_objet' => 'Nombre de campo incorrecto @name@ para objeto de tipo @type@',
'avis_colonne_inexistante' => 'La columna @col@ no existe',
'avis_echec_syndication_01' => 'La sindicaci&oacute;n fall&oacute;: el &laquo;backend&raquo; indicado es indescifrable o no propone ning&uacute;n art&iacute;culo.',
'avis_echec_syndication_02' => 'La sindicaci&oacute;n fall&oacute;: imposible acceder al &laquo;backend&raquo; de este sitio.',
'avis_erreur' => 'Error: ver aqui abajo',
'avis_erreur_connexion' => 'Error de conexi&oacute;n',
'avis_erreur_cookie' => 'problema de cookie ',
'avis_erreur_fonction_contexte' => 'Error de programaci&oacute;n. No se debe llamar a esta funci&oacute;n en este contexto.',
'avis_erreur_mysql' => 'Error SQL',
'avis_erreur_sauvegarde' => 'Error al hacer la copia de respaldo (@type@ @id_objet@)!',
'avis_erreur_visiteur' => 'Probleme de acceso al espacio privado',

// B
'barre_a_accent_grave' => 'Insertar una A may&uacute;scula con acento grave',
'barre_aide' => 'Utiliza los atajos tipogr&aacute;ficos para mejorar la paginaci&oacute;n',
'barre_e_accent_aigu' => 'Insertar una E may&uacute;scula con tilde',
'barre_eo' => 'Insertar una E en la O',
'barre_eo_maj' => 'Insertar una E en la O may&uacute;scula',
'barre_euro' => 'Insertar el s&iacute;mbolo &euro;',
'barre_gras' => 'Poner en {{negrita}}',
'barre_guillemets' => 'Poner entre &laquo;comillas&raquo;',
'barre_guillemets_simples' => 'Poner entre &#147;comillas de segundo nivel”',
'barre_intertitre' => 'Transformar en {{{inter-t&iacute;tulo}}}',
'barre_italic' => 'Poner en {cursiva}',
'barre_lien' => 'Transformar en [enlace hipertexto->http://...]',
'barre_lien_input' => 'Indica la direcci&oacute;n de tu enlace. Puedes indicar un direcci&oacute;n web bajo la forma http://www.talsitio.org/carpeta/ o simplemente indicar el n&uacute;mero de un art&iacute;culo de este sitio.',
'barre_note' => 'Transformar en [[Nota de pi&eacute; de p&aacute;gina]]',
'barre_paragraphe' => 'Crear un p&aacute;rrafo',
'barre_quote' => '<quote>Citar un mensaje</quote>',
'bouton_ajouter_document' => 'A&ntilde;adir un documento',
'bouton_ajouter_image' => 'A&ntilde;adir una imagen',
'bouton_ajouter_image_document' => 'A&ntilde;adir una imagen o&nbsp;un&nbsp;documento',
'bouton_changer' => 'Cambiar',
'bouton_chercher' => 'Buscar',
'bouton_choisir' => 'Elegir',
'bouton_download' => 'Descargar',
'bouton_enregistrer' => 'Guardar',
'bouton_radio_desactiver_messagerie_interne' => 'Desactivar la mensajer&iacute;a interna',
'bouton_radio_envoi_annonces' => 'Enviar anuncios editoriales',
'bouton_radio_non_envoi_annonces' => 'No enviar anuncios',
'bouton_radio_non_envoi_liste_nouveautes' => 'No enviar la lista de novedades',
'bouton_recharger_page' => 'Actualizar esta p&aacute;gina',
'bouton_telecharger' => 'Subir',
'bouton_valider' => 'Validar',

// C
'cal_apresmidi' => 'tarde',
'cal_jour_entier' => 'd&iacute;a entero',
'cal_matin' => 'ma&ntilde;ana',
'cal_par_jour' => 'calendario por d&iacute;a',
'cal_par_mois' => 'calendario por mes',
'cal_par_semaine' => 'calendario por semana',
'choix_couleur_interface' => 'color',
'choix_interface' => 'Selecci&oacute;n de la interfase',
'colonne' => 'Columna',
'confirm_changer_statut' => 'Cuidado, est&aacute;s cambiando el estado de este elemento. &iquest;Lo confirmas?',
'correcte' => 'correcta',

// D
'date_aujourdhui' => 'hoy',
'date_avant_jc' => 'aC',
'date_dans' => 'en @delai@',
'date_de_mois_1' => '@j@ de @nommois@',
'date_de_mois_10' => '@j@ de @nommois@',
'date_de_mois_11' => '@j@ de @nommois@',
'date_de_mois_12' => '@j@ de @nommois@',
'date_de_mois_2' => '@j@ de @nommois@',
'date_de_mois_3' => '@j@ de @nommois@',
'date_de_mois_4' => '@j@ de @nommois@',
'date_de_mois_5' => '@j@ de @nommois@',
'date_de_mois_6' => '@j@ de @nommois@',
'date_de_mois_7' => '@j@ de @nommois@',
'date_de_mois_8' => '@j@ de @nommois@',
'date_de_mois_9' => '@j@ de @nommois@',
'date_demain' => 'ma&ntilde;ana',
'date_fmt_heures_minutes' => '@h@h@m@min',
'date_fmt_jour_heure' => '@jour@ a las @heure@',
'date_fmt_jour_mois' => '@jour@ de @nommois@',
'date_fmt_jour_mois_annee' => '@jour@ de @nommois@ de @annee@',
'date_fmt_mois_annee' => '@nommois@ de @annee@',
'date_fmt_nomjour_date' => 'el @nomjour@ @date@',
'date_heures' => 'horas',
'date_hier' => 'ayer',
'date_il_y_a' => 'hace @delai@',
'date_jnum1' => '1ro',
'date_jnum10' => '10',
'date_jnum11' => '11',
'date_jnum12' => '12',
'date_jnum13' => '13',
'date_jnum14' => '14',
'date_jnum15' => '15',
'date_jnum16' => '16',
'date_jnum17' => '17',
'date_jnum18' => '18',
'date_jnum19' => '19',
'date_jnum2' => '2',
'date_jnum20' => '20',
'date_jnum21' => '21',
'date_jnum22' => '22',
'date_jnum23' => '23',
'date_jnum24' => '24',
'date_jnum25' => '25',
'date_jnum26' => '26',
'date_jnum27' => '27',
'date_jnum28' => '28',
'date_jnum29' => '29',
'date_jnum3' => '3',
'date_jnum30' => '30',
'date_jnum31' => '31',
'date_jnum4' => '4',
'date_jnum5' => '5',
'date_jnum6' => '6',
'date_jnum7' => '7',
'date_jnum8' => '8',
'date_jnum9' => '9',
'date_jour_1' => 'Domingo',
'date_jour_1_abbr' => 'dom',
'date_jour_1_initiale' => 'd',
'date_jour_2' => 'Lunes',
'date_jour_2_abbr' => 'lun',
'date_jour_2_initiale' => 'l',
'date_jour_3' => 'Martes',
'date_jour_3_abbr' => 'mar',
'date_jour_3_initiale' => 'm',
'date_jour_4' => 'Mi&eacute;rcoles',
'date_jour_4_abbr' => 'mie',
'date_jour_4_initiale' => 'm',
'date_jour_5' => 'Jueves',
'date_jour_5_abbr' => 'jue',
'date_jour_5_initiale' => 'j',
'date_jour_6' => 'Viernes',
'date_jour_6_abbr' => 'vie',
'date_jour_6_initiale' => 'v',
'date_jour_7' => 'S&aacute;bado',
'date_jour_7_abbr' => 'sab',
'date_jour_7_initiale' => 's',
'date_jours' => 'd&iacute;as',
'date_minutes' => 'minutos',
'date_mois' => 'meses',
'date_mois_1' => 'enero',
'date_mois_10' => 'octubre',
'date_mois_11' => 'noviembre',
'date_mois_12' => 'diciembre',
'date_mois_2' => 'febrero',
'date_mois_3' => 'marzo',
'date_mois_4' => 'abril',
'date_mois_5' => 'mayo',
'date_mois_6' => 'junio',
'date_mois_7' => 'julio',
'date_mois_8' => 'agosto',
'date_mois_9' => 'septiembre',
'date_saison_1' => 'invierno',
'date_saison_2' => 'primavera',
'date_saison_3' => 'verano',
'date_saison_4' => 'oto&ntilde;o',
'date_secondes' => 'segundos',
'date_semaines' => 'semanas',
'date_un_mois' => 'mes',
'date_une_heure' => 'hora',
'date_une_minute' => 'minuto',
'date_une_seconde' => 'segundo',
'date_une_semaine' => 'semana',
'dirs_commencer' => 'Para empezar realmente la instalaci&oacute;n',
'dirs_preliminaire' => 'Preliminar: <b>Regular los derechos de acceso</b>',
'dirs_probleme_droits' => 'Problema de derechos de acceso',
'dirs_repertoires_absents' => '<p><b>No se pudieron encontrar las siguientes carpetas:</b></p><ul>@bad_dirs@.</ul> </b>
<p>Es probable que se deba a un problema de escritura entre may&uacute;sculas y min&uacute;sculas.
  Verifique que las may&uacute;sculas y min&uacute;sculas de los nombres de estas carpetas corresponden a lo se visualiza a continuaci&oacute;n; si no es el caso, cambia el nombre de las carpetas con tu software de FTP, de modo que se corrijan los errores.</p>
  <p>Cuando hayas hecho esta operaci&oacute;n podr&aacute;s  ',
'dirs_repertoires_suivants' => '<p><b>Las carpetas siguientes no est&aacute;n accesibles en escritura&nbsp;:</b></p><ul>@bad_dirs@.</ul>
<p>Para solucionar el problema debes utilizar un cliente FTP para cambiar los derechos de acceso a cada una
de las carpetas mencionadas. El procedimiento se explica detalladamente en la gu&iacute;a de instalaci&oacute;n.</p>
<p>Una vez terminado este proceso, podr&aacute;s ',
'double_occurrence' => 'Doble ocurrencia de @balise@',

// E
'en_cours' => 'en curso',
'entree_dimensions' => 'Dimensiones',
'entree_titre_document' => 'T&iacute;tulo del documento',
'entree_titre_image' => 'T&iacute;tulo de la imagen',
'envoi_via_le_site' => 'Env&iacute;o a trav&eacute;s del sitio',
'erreur' => 'Error',
'erreur_balise_non_fermee' => '&uacute;ltima baliza no cerrada:',
'erreur_texte' => 'error(es)',
'etape' => 'Etapa',

// F
'fichier_introuvable' => 'No se encuentra el archivo @fichier@',
'form_auteur_confirmation' => 'Confirma tu direcci&oacute;n de correo',
'form_auteur_email_modifie' => 'Tu direcci&oacute;n de correo fue modificada',
'form_auteur_envoi_mail_confirmation' => 'Se te acaba de enviar un mensaje de confirmaci&oacute;n a @email@. Tienes que visitar la p&aacute;gina web indicada en ese mensaje para validar tu direcci&oacute;n de correo.',
'form_auteur_mail_confirmation' => 'Hola,

Has solicitado cambiar tu direcci&oacute;n de correo.
Para confirmar tu nueva direcci&oacute;n, alcanza con visitar la p&aacute;gina
siguiente:

    @url@
Caso contrario, la solicitud ser&aacute; simplemente ignorada.
',
'form_deja_inscrit' => 'Ya est&aacute;s inscrito.',
'form_email_non_valide' => 'La direcci&oacute;n de correo electr&oacute;nico no es v&aacute;lida.',
'form_forum_access_refuse' => 'Ya no tienes acceso a este sitio.',
'form_forum_bonjour' => 'Hola, @nom@,',
'form_forum_email_deja_enregistre' => 'Esta direcci&oacute;n de correo electr&oacute;nico ya est&aacute; registrada, por lo que puedes utilizar tu contrase&ntilde;a habitual.',
'form_forum_identifiant_mail' => 'Hemos enviado tu nuevo identificador por correo electr&oacute;nico.',
'form_forum_identifiants' => 'Identificadores personales',
'form_forum_indiquer_nom_email' => 'Indica aqu&iacute; tu nombre y direcci&oacute;n de correo electr&oacute;nico. Se te enviar&aacute; de inmediato por correo electr&oacute;nico tu identificador personal.',
'form_forum_login' => 'login:',
'form_forum_message_auto' => '(esto es un mensaje autom&aacute;tico)',
'form_forum_pass' => 'contrase&ntilde;a:',
'form_forum_probleme_mail' => 'Problema con el correo electr&oacute;nico: no se puede enviar el identificador.',
'form_forum_voici1' => 'Esta es tu identificaci&oacute;n para participar
en los foros del sitio "@nom_site_spip@" (@adresse_site@):',
'form_forum_voici2' => 'Esta es tu identificaci&oacute;n para proponer art&iacute;culos
en el sitio "@nom_site_spip@" (@adresse_login@):',
'form_indiquer_email' => 'Indica tu direcci&oacute;n de correo electr&oacute;nico.',
'form_indiquer_nom' => 'Indica tu nombre.',
'form_indiquer_nom_site' => 'Indica el nombre de tu sitio Web.',
'form_pet_adresse_site' => 'Direcci&oacute;n de tu sitio',
'form_pet_aucune_signature' => 'No hay ninguna firma que corresponda a este c&oacute;digo...',
'form_pet_confirmation' => 'Ratifica tu firma: ',
'form_pet_deja_enregistre' => 'Este sitio ya est&aacute; registrado',
'form_pet_deja_signe' => 'Ya has firmado este texto.',
'form_pet_envoi_mail_confirmation' => 'Se acaba de enviar un mensaje de confirmaci&oacute;n a @email@. Tienes que ingresar a la direcci&oacute;n Web que contiene para validar tu firma.',
'form_pet_mail_confirmation' => 'Hola,

Has solicitado a&ntilde;adir tu firma a:
@titre@.

Con la siguiente informaci&oacute;n:

    Nombre: @nom_email@
    Sitio: @nom_site@ - @url_site@
    @message@

IMPORTANTE...
Para confirmar tu firma, debes ingresar a
la direcci&oacute;n web indicada a continuaci&oacute;n (de lo contrario, tu firma
no podr&aacute; ser tomada en cuenta):

    @url@


Gracias por tu participaci&oacute;n
',
'form_pet_message_commentaire' => '&iquest;Un mensaje, un comentario?',
'form_pet_nom_site2' => 'Nombre de tu sitio Web',
'form_pet_probleme_liens' => 'Ingresa nuevamente tu mensaje, quitando los enlaces hypertexto.',
'form_pet_probleme_technique' => 'Problema t&eacute;cnico, las firmas est&aacute;n temporalmente suspendidas.',
'form_pet_signature_pasprise' => 'Tu firma no ha sido tomada en cuenta.',
'form_pet_signature_validee' => 'Tu firma est&aacute; validada. &iexcl;Gracias!',
'form_pet_site_deja_enregistre' => 'Este sitio ya est&aacute; registrado',
'form_pet_url_invalide' => 'La URL que has indicado no es v&aacute;lida.',
'form_pet_votre_email' => 'Tu direcci&oacute;n de correo electr&oacute;nico',
'form_pet_votre_nom' => 'Tu nombre o pseud&oacute;nimo',
'form_pet_votre_site' => 'Si tienes un sitio Web, puedes indicarlo a continuaci&oacute;n',
'form_prop_confirmer_envoi' => 'Confirmar el env&iacute;o',
'form_prop_description' => 'Descripci&oacute;n/comentario',
'form_prop_enregistre' => 'Tu propuesta ha sido registrada, aparecer&aacute; en l&iacute;nea despu&eacute;s de la validaci&oacute;n por el equipo responsable de este sitio.',
'form_prop_envoyer' => 'Enviar un mensaje',
'form_prop_indiquer_email' => 'Indica una direcci&oacute;n de correo electr&oacute;nico v&aacute;lida',
'form_prop_indiquer_nom_site' => 'Indica el nombre del sitio.',
'form_prop_indiquer_sujet' => 'Indicar un tema',
'form_prop_message_envoye' => 'Mensaje enviado',
'form_prop_nom_site' => 'Nombre del sitio',
'form_prop_non_enregistre' => 'Tu propuesta no fue registrada.',
'form_prop_sujet' => 'Asunto',
'form_prop_url_site' => 'Direcci&oacute;n (URL) del sitio',
'forum_acces_refuse' => 'Ya no tienes acceso a estos foros.',
'forum_attention_dix_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> tu mensaje debe tener al menos diez caracteres.',
'forum_attention_trois_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> el t&iacute;tulo debe tener al menos tres caracteres.',
'forum_attention_trop_caracteres' => '<b>&iexcl;Atenci&oacute;n!</b> el mensaje es demasiado largo (@compte@ caracteres): para poder guardarlo, no debe sobrepasar los @max@ caracteres.',
'forum_avez_selectionne' => 'Has seleccionado:',
'forum_cliquer_retour' => 'Pinchar <a href=\'@retour_forum@\'>aqu&iacute;</a> para continuar.',
'forum_forum' => 'foro',
'forum_info_modere' => 'Este foro est&aacute; moderado a priori: tu contribuci&oacute;n no aparecer&aacute; hasta haber sido validada por la administraci&oacute;n del sitio.',
'forum_lien_hyper' => '<b>Enlace hipertexto</b> (opcional)',
'forum_message_definitif' => 'Mensaje definitivo: enviar al sitio',
'forum_message_trop_long' => 'Tu mensaje es demasiado largo. S&oacute;lo se admite un m&aacute;ximo de 20.000 caracteres.',
'forum_ne_repondez_pas' => 'No respondas a este correo electr&oacute;nico, sino en el foro en la siguiente direcci&oacute;n:',
'forum_non_inscrit' => 'No est&aacute;s inscrita o inscrito, o bien la direcci&oacute;n o la contrase&ntilde;a son err&oacute;neas.',
'forum_page_url' => '(Si tu mensaje se refiere a un art&iacute;culo publicado en Internet, o a una p&aacute;gina que contiene m&aacute;s informaciones, indica a continuaci&oacute;n el t&iacute;tulo de la p&aacute;gina y su direcci&oacute;n URL.)',
'forum_par_auteur' => 'por @auteur@',
'forum_poste_par' => 'Mensaje enviado @parauteur@ a como respuesta al art&iacute;culo <i>@titre@</i>.',
'forum_probleme_database' => 'Problema de la base de datos, tu mensaje no ha sido registrado.',
'forum_qui_etes_vous' => '<b>&iquest;Qui&eacute;n eres?</b> (opcional)',
'forum_texte' => 'Texto de tu mensaje:',
'forum_titre' => 'T&iacute;tulo:',
'forum_titre_erreur' => 'Error...',
'forum_url' => 'URL:',
'forum_valider' => 'Validar la elecci&oacute;n',
'forum_voir_avant' => 'Ver este mensaje antes de enviarlo',
'forum_votre_email' => 'Tu direcci&oacute;n de correo electr&oacute;nico:',
'forum_votre_nom' => 'Tu nombre (o seud&oacute;nimo):',
'forum_vous_enregistrer' => 'Para participar en este foro, previamente debes registrarte.
Gracias por indicar a continuaci&oacute;n el identificador personal que se te ha
suministrado. Si no est&aacute;s inscrito/a, debes',
'forum_vous_inscrire' => 'inscribirte.',

// I
'ical_texte_rss_articles' => 'El archivo &laquo;backend&raquo; de art&iacute;culos de este sitio se encuentra en la direcci&oacute;n:',
'ical_texte_rss_articles2' => 'Tambi&eacute;n puedes obtener archivos &laquo;backend&raquo; para los art&iacute;culos de cada secci&oacute;n de este sitio:',
'ical_texte_rss_breves' => 'Adem&aacute;s existe un archivo que contiene las breves del sitio. Especificando el n&uacute;mero de secci&oacute;n, se pueden obtener &uacute;nicamente las breves de &eacute;sta.',
'icone_a_suivre' => 'Mis tareas',
'icone_admin_site' => 'Administraci&oacute;n del sitio',
'icone_agenda' => 'Agenda',
'icone_aide_ligne' => 'Ayuda en l&iacute;nea',
'icone_articles' => 'Art&iacute;culos',
'icone_auteurs' => 'Autoras y autores',
'icone_breves' => 'Breves',
'icone_brouteur' => 'Navegaci&oacute;n r&aacute;pida',
'icone_configuration_site' => 'Configuraci&oacute;n del sitio',
'icone_configurer_site' => 'Configurar el sitio',
'icone_creer_nouvel_auteur' => 'Crear un nuevo autor o autora',
'icone_creer_rubrique' => 'Crear una secci&oacute;n',
'icone_creer_sous_rubrique' => 'Crear una subsecci&oacute;n',
'icone_deconnecter' => 'Desconectarse',
'icone_discussions' => 'Discusiones',
'icone_doc_rubrique' => 'Documentos de las secciones',
'icone_ecrire_article' => 'Nuevo art&iacute;culo',
'icone_edition_site' => 'Edici&oacute;n del sitio',
'icone_forum_administrateur' => 'Foro de administradoras y administradores',
'icone_forum_suivi' => 'Seguimiento de los foros',
'icone_gestion_langues' => 'Gesti&oacute;n de idiomas',
'icone_informations_personnelles' => 'Informaciones personales',
'icone_interface_complet' => 'Interfaz completa',
'icone_interface_simple' => 'Interfaz simple',
'icone_maintenance_site' => 'Mantenimiento del sitio',
'icone_messagerie_personnelle' => 'Mensajer&iacute;a personal',
'icone_mots_cles' => 'Palabras clave',
'icone_nouvelle_breve' => 'Nueva breve',
'icone_repartition_actuelle' => 'Mostrar el reparto actual',
'icone_repartition_debut' => 'Mostrar el reparto desde el comienzo',
'icone_repartition_visites' => 'Distribuci&oacute;n de las visitas',
'icone_rubriques' => 'Secciones',
'icone_sauver_site' => 'Respaldo del sitio',
'icone_site_entier' => 'Todo el sitio',
'icone_sites_references' => 'Sitios referenciados',
'icone_statistiques' => 'Estad&iacute;sticas del sitio',
'icone_statistiques_visites' => 'Estad&iacute;sticas de visitas',
'icone_suivi_activite' => 'Seguir la vida del sitio',
'icone_suivi_actualite' => 'Evoluci&oacute;n del&nbsp;sitio',
'icone_suivi_forums' => 'Seguir y administrar los foros',
'icone_suivi_pettions' => 'Gesti&oacute;n de las peticiones',
'icone_suivi_revisions' => 'Modificaciones de art&iacute;culos',
'icone_supprimer_document' => 'Suprimir este documento',
'icone_supprimer_image' => 'Suprimir esta imagen',
'icone_supprimer_message' => 'Suprimir este mensaje',
'icone_tous_articles' => 'Todos tus art&iacute;culos',
'icone_tous_auteur' => 'Todos los autores y autoras',
'icone_valider_message' => 'Validar este mensaje',
'icone_visiter_site' => 'Visitar el sitio',
'icone_voir_en_ligne' => 'Ver en l&iacute;nea',
'image_tourner_180' => 'Rotaci&oacute;n de 180&deg;',
'image_tourner_droite' => 'Rotaci&oacute;n de 90&deg; a la derecha',
'image_tourner_gauche' => 'Rotaci&oacute;n de 90&deg; a la izquierda',
'img_indisponible' => 'imagen indisponible',
'impossible' => 'imposible',
'info_a_suivre' => 'MIS TAREAS&nbsp;&raquo;',
'info_a_valider' => '[a validar]',
'info_acces_interdit' => 'Acceso prohibido',
'info_acces_refuse' => 'Acceso rechazado',
'info_action' => 'Acci&oacute;n: @action@',
'info_administrer_rubriques' => 'Puedes administrar esta secci&oacute;n y sus subsecciones',
'info_adresse_non_indiquee' => '&iexcl;No has indicado la direcci&oacute;n a probar&nbsp;!',
'info_aide' => 'AYUDA:',
'info_ajouter_mot' => 'A&ntilde;adir esta palabra',
'info_annonce' => 'Anuncio',
'info_annonces_generales' => 'Anuncios generales',
'info_article_propose' => 'Art&iacute;culo propuesto',
'info_article_publie' => 'Art&iacute;culo publicado',
'info_article_redaction' => 'Art&iacute;culo en curso',
'info_article_refuse' => 'Art&iacute;culo rechazado',
'info_article_supprime' => 'Art&iacute;culo suprimido',
'info_articles' => 'Art&iacute;culos',
'info_articles_a_valider' => 'Los art&iacute;culos a validar',
'info_articles_nb' => '@nb@ art&iacute;culos',
'info_articles_proposes' => 'Art&iacute;culos propuestos',
'info_articles_un' => '1 art&iacute;culo',
'info_auteurs_nombre' => 'Autora(s) y autor(es):',
'info_authentification_ftp' => 'Autentificaci&oacute;n (por FTP).',
'info_bloquer_lien' => 'bloquear este enlace',
'info_breves_02' => 'Breves',
'info_breves_2' => 'breves',
'info_breves_nb' => '@nb@ breves',
'info_breves_un' => '1 breve',
'info_breves_valider' => 'Breves a validar',
'info_connexion_refusee' => 'Conexi&oacute;n rechazada',
'info_contact_developpeur' => 'Debes contactar con un programador.',
'info_contenance' => 'Este sitio contiene:',
'info_contribution' => 'contribuciones del foro',
'info_copyright' => '@spip@ es un software libre distribu&iacute;do @lien_gpl@.',
'info_copyright_doc' => 'Para mayor informaci&oacute;n, ver el sitio <a href="@spipnet@">http://www.spip.net/es</a>.',
'info_copyright_gpl' => 'bajo licencia GPL',
'info_cours_edition' => 'Tus art&iacute;culos en curso de redacci&oacute;n',
'info_creer_repertoire' => 'Debes crear un archivo o una carpeta llamada',
'info_creer_repertoire_2' => 'en el directorio <b>@repertoire@</b>, y luego',
'info_creer_vignette' => 'creaci&oacute;n autom&aacute;tica de la miniatura',
'info_deplier' => 'Desplegar',
'info_descriptif_nombre' => 'descripcci&oacute;n(es):',
'info_description' => 'Descripci&oacute;n:',
'info_description_2' => 'Descripci&oacute;n:',
'info_dimension' => 'Dimensiones',
'info_document' => 'Documento',
'info_document_indisponible' => 'Este documento no est&aacute; disponible',
'info_documents' => 'Documentos',
'info_documents_nb' => '@nb@ documentos',
'info_documents_un' => '1 documento',
'info_echange_message' => 'En funci&oacute;n de las preferencias, SPIP permite el intercambio de mensajes y la existencia de foros internos
 privados entre los participantes del sitio. Esta funcionalidad
se puede activar o desactivar .',
'info_ecire_message_prive' => 'Escribir un mensaje privado',
'info_email_invalide' => 'La direcci&oacute;n de correo electr&oacute;nico no es v&aacute;lida.',
'info_en_cours_validation' => 'Tus art&iacute;culos en curso',
'info_en_ligne' => 'Actualmente en l&iacute;nea',
'info_envoyer_message_prive' => 'Enviar un mensaje privado a este autor o autora',
'info_erreur_requete' => 'Error en la petici&oacute;n:',
'info_erreur_squelette2' => 'No hay ning&uacute;n esqueleto <b>@fichier@</b>  disponible...',
'info_erreur_systeme' => 'Error del sistema (errno @errsys@)',
'info_erreur_systeme2' => 'El disco duro puede estar lleno o la base de datos da&ntilde;ada.<br />
 <font color=\'red\'>Intenta <a href=\'@script@\'>reparar la base</a>,
 o contacta tu hospedaje.</font>',
'info_fini' => '&iexcl;Terminado!',
'info_format_image' => 'Formatos de imagen utilizables para los iconos  @gd_formats@.',
'info_format_non_defini' => 'formato no definido',
'info_grand_ecran' => 'Pantalla completa',
'info_image_aide' => 'Ayuda',
'info_image_process_titre' => 'M&eacute;todo de creaci&oacute;n de miniaturas',
'info_impossible_lire_page' => '<b>&iexcl;Error !</b> Imposible leer la p&aacute;gina <tt><html>@test_proxy@</html></tt> a trav&eacute;s del "proxy" <tt>',
'info_inclusion_directe' => 'Inclusi&oacute;n directa:',
'info_inclusion_vignette' => 'Inclusi&oacute;n del icono',
'info_installation_systeme_publication' => 'Instalaci&oacute;n del sistema de publicaci&oacute;n...',
'info_installer_documents' => 'Puedes instalar autom&aacute;ticamente todos los documentos contenidos en el directorio @upload@.',
'info_installer_ftp' => 'Con derechos de administraci&oacute;n, puedes instalar archivos (v&iacute;a FTP) en la carpeta @upload@ para luego poder seleccionarlos directamente aqu&iacute;.',
'info_installer_images' => 'Puedes instalar im&aacute;genes de formato JPEG, GIF y PNG.',
'info_installer_images_dossier' => 'Instalar im&aacute;genes en la carpeta @upload@ para luego poder seleccionarlas directamente aqu&iacute;.',
'info_installer_tous_documents' => 'Instalar todos los documentos',
'info_interface_complete' => 'Interfaz completa',
'info_interface_simple' => 'Interfaz simple',
'info_joindre_document_article' => 'Puedes adjuntar a este art&iacute;culo documentos de tipo',
'info_joindre_document_rubrique' => 'Puedes adjuntar a esta secci&oacute;n documentos de tipo',
'info_joindre_documents_article' => 'Puedes adjuntar a tu art&iacute;culo documentos de tipo',
'info_l_article' => 'el art&iacute;culo',
'info_la_breve' => 'la breve',
'info_la_rubrique' => 'la secci&oacute;n',
'info_langue_principale' => 'Idioma principal del sitio',
'info_largeur_vignette' => '@largeur_vignette@ &times; @hauteur_vignette@ p&iacute;xeles',
'info_les_auteurs_1' => 'por @les_auteurs@',
'info_logo_format_interdit' => 'S&oacute;lo se autorizan los logos de formatos @formats@.',
'info_logo_max_poids' => 'Los logos deben obligatoriamente pesar menos de @maxi@ (el archivo pesa @actuel@).',
'info_logo_max_taille' => 'Los logos deben obligatoriamente medir menos de @maxi@ (el archivo mide @actuel@).',
'info_mail_fournisseur' => 'tu@proveedor.com',
'info_message_2' => 'MENSAJE',
'info_message_supprime' => 'Mensaje suprimido',
'info_messages_nb' => '@nb@ mensajes',
'info_messages_un' => '1 mensaje',
'info_mise_en_ligne' => 'Fecha de puesta en l&iacute;nea',
'info_modification_parametres_securite' => 'modificaciones de los par&aacute;metros de seguridad',
'info_mois_courant' => 'En el mes actual de: ',
'info_mot_cle_ajoute' => 'La palabra clave siguiente ha sido a&ntilde;adida al art&iacute;culo',
'info_multi_herit' => 'Idioma por omisi&oacute;n',
'info_multi_langues_soulignees' => 'Los <u>idiomas subrayados</u> disponen de una traducci&oacute;n los textos de la interfaz. Si los seleccionas, diversos elementos del sitio p&uacute;blico (fechas, formularios) ser&aacute;n traducidos autom&aacute;ticamente. En los idiomas no subrayados, dichos elementos aparecer&aacute;n en la lengua principal del sitio.',
'info_multilinguisme' => 'Multiling&uuml;ismo',
'info_nom_non_utilisateurs_connectes' => 'Tu nombre no aparece en la lista de personas conectadas',
'info_nom_utilisateurs_connectes' => 'Tu nombre aparece en la lista de personas conectadas.',
'info_nombre_en_ligne' => 'Actualmente en l&iacute;nea',
'info_non_resultat' => 'No se han encontrado resultados para la b&uacute;squeda "@cherche_mot@"',
'info_non_utilisation_messagerie' => 'No utilizar la mensajer&iacute;a interna.',
'info_nouveau_message' => '<b>&iexcl;Tienes un nuevo mensaje!</b>',
'info_nouveaux_messages' => 'Tienes @total_messages@ mensajes nuevos ',
'info_numero_abbreviation' => 'N&deg;&nbsp;',
'info_obligatoire' => 'Esta informaci&oacute;n es obligatoria',
'info_panne_site_syndique' => 'El sitio sindicado tiene problemas',
'info_pense_bete' => 'Recordatorio para memorizar',
'info_petit_ecran' => 'Pantalla peque&ntilde;a',
'info_petition_close' => 'Ya no se firma',
'info_pixels' => 'p&iacute;xeles',
'info_plusieurs_mots_trouves' => 'Hemos encontrado varias palabras clave para "@cherche_mot@":',
'info_popularite_5' => 'Popularidad:',
'info_portfolio' => 'Portafolio',
'info_portfolio_automatique' => 'Portafolio autom&aacute;tico',
'info_premier_resultat' => '[@debut_limit@ primeros resultados sobre @total@]',
'info_premier_resultat_sur' => '[@debut_limit@ primeros resultados sobre @total@]',
'info_probleme_grave' => 'problema de',
'info_propose_1' => '[@nom_site_spip@] Propuesto: @titre@',
'info_propose_2' => 'Art&iacute;culo propuesto
------------------',
'info_propose_3' => 'El art&iacute;culo "@titre@" fue propuesto para ser publicado.',
'info_propose_4' => 'Est&aacute;s invitado/a a consultarlo y a dar tu opini&oacute;n',
'info_propose_5' => 'en el foro que le concierne. Est&aacute; disponible en la direcci&oacute;n: ',
'info_publie_01' => 'El art&iacute;culo "@titre@" ha sido validado por @connect_nom@.',
'info_publie_1' => '[@nom_site_spip@] PUBLICADO: @titre@',
'info_publie_2' => 'Art&iacute;culo publicado
-------------------',
'info_rechercher' => 'Buscar',
'info_rechercher_02' => 'Buscar',
'info_remplacer_vignette' => 'Reemplazar el icono predeterminado por una imagen de tu elecci&oacute;n&nbsp;:',
'info_retablir_lien' => 'restablecer el enlace',
'info_retirer_mot' => 'Retirar la palabra',
'info_retirer_mots' => 'Retirar todas las palabras',
'info_rubriques_nb' => '@nb@ secciones',
'info_rubriques_un' => '1 secci&oacute;n',
'info_sans_titre_2' => 'sin t&iacute;tulo',
'info_selectionner_fichier' => 'Puedes seleccionar un documento del directorio @upload@',
'info_selectionner_fichier_2' => 'Seleccionar un documento...',
'info_signature_supprimee' => 'Firma eliminada',
'info_signature_supprimee_erreur' => 'Error: este c&oacute;digo de eliminaci&oacute;n no  corresponde a ninguna firma',
'info_site_attente' => 'Sitio Web en espera de validaci&oacute;n',
'info_site_reference' => 'Sitio referenciado en l&iacute;nea',
'info_site_refuse' => 'Sitio Web rechazado',
'info_sites_nb' => '@nb@ sitios',
'info_sites_referencer' => 'Referenciar un sitio',
'info_sites_un' => '1 sitio',
'info_supprimer_vignette' => 'Suprimir este icono',
'info_symbole_bleu' => 'El s&iacute;mbolo <b>azul</b> representa un <b>recordatorio personal</b>, o sea una manera de recordar algo.',
'info_symbole_jaune' => 'El s&iacute;mbolo <b>amarillo</b> representa un <b>anuncio para todos</b>: s&oacute;lo es modificable por las/os administradoras/es del sitio, y es visible por todos los redactores.',
'info_symbole_vert' => 'El s&iacute;mbolo <b>verde</b> indica los  <b>mensajes intercambiados con otras personas</b> del sitio.',
'info_syndication' => 'sindicaci&oacute;n:',
'info_syndication_articles' => 'art&iacute;culo(s)',
'info_telecharger' => 'Subir desde tu ordenador:',
'info_telecharger_nouveau_logo' => 'Subir un nuevo logotipo:',
'info_telecharger_ordinateur' => 'Subir desde tu ordenador:',
'info_tous_resultats_enregistres' => '[todos los resultados son registrados]',
'info_tout_afficher' => 'Mostrar todo',
'info_travaux_texte' => 'Este sitio todav&iacute;a no est&aacute; configurado. Vuelve m&aacute;s adelante...',
'info_travaux_titre' => 'Sitio en curso de modificaci&oacute;n',
'info_trop_resultat' => 'Demasiados resultados para la b&uacute;squeda de "@cherche_mot@" . Precise los criterios.',
'info_utilisation_messagerie_interne' => 'Utilizas la mensajer&iacute;a interna del sitio.',
'info_valider_lien' => 'validar este enlace',
'info_verifier_image' => ', verifique si las im&aacute;genes han sido corresctamente transferidas.',
'info_vignette_defaut' => 'Icono predeterminado',
'info_vignette_personnalisee' => 'Icono personalizado',
'info_visite' => 'visita:',
'info_visites' => 'visitas:',
'info_vos_rendez_vous' => 'Tus citas',
'info_zoom' => 'zoom',
'infos_vos_pense_bete' => 'Tus  recordatorios',
'item_breve_proposee' => 'Breve propuesta',

// L
'lien_afficher_icones_seuls' => 'Mostrar s&oacute;lo los iconos',
'lien_afficher_texte_icones' => 'Mostrar iconos y texto',
'lien_afficher_texte_seul' => 'Mostrar s&oacute;lo el texto',
'lien_liberer' => 'Liberar',
'lien_liberer_tous' => 'liberar estos art&iacute;culos',
'lien_nouvea_pense_bete' => 'Nuevo recordatorio',
'lien_nouveau_message' => 'Nuevo mensaje',
'lien_nouvelle_annonce' => 'Nuevo anuncio',
'lien_petitions' => 'Petici&oacute;n',
'lien_popularite' => 'Popularidad: @popularite@%',
'lien_racine_site' => 'Ra&iacute;z del sitio',
'lien_reessayer' => 'reintentar',
'lien_repondre_message' => 'Responder a este mensaje',
'lien_supprimer' => 'Suprimir',
'lien_tout_afficher' => 'Mostrar todo',
'lien_visite_site' => 'Visitar este sitio',
'lien_visites' => '@visites@ visitas.',
'lien_voir_auteur' => 'Ver esta autor/a',
'ligne' => 'L&iacute;nea',
'login' => 'Conexi&oacute;n',
'login_acces_prive' => 'acceso al espacio privado',
'login_autre_identifiant' => 'conectarse con otro nombre de usuario o usuaria',
'login_cookie_accepte' => 'Configura tu navegador para que las acepte (al menos para este sitio).',
'login_cookie_oblige' => 'Para identificarte de manera segura en este sitio, tienes que aceptar las "cookies".',
'login_deconnexion_ok' => 'Desconexi&oacute;n efectuada.',
'login_erreur_pass' => 'Error de contrase&ntilde;a.',
'login_espace_prive' => 'espacio privado',
'login_identifiant_inconnu' => 'El nombre de usuario o usuaria &laquo;@login@&raquo; es desconocido.',
'login_login' => 'Nombre de usuario o usuaria:',
'login_login2' => 'Login (identificador de conexi&oacute;n al sitio):',
'login_login_pass_incorrect' => '(Identificador o contrase&ntilde;a incorrecta.)',
'login_motpasseoublie' => '&iquest;contrase&ntilde;a&nbsp;olvidada?',
'login_non_securise' => 'Atenci&oacute;n, este formulario no est&aacute; asegurado.
 Si no deseas que tu contrase&ntilde;a pueda ser interceptada en la red, activa JavaScript en tu navegador y',
'login_nouvelle_tentative' => 'Nuevo intento',
'login_par_ici' => 'Est&aacute;s registrado o registrada... por aqu&iacute;...',
'login_pass2' => 'Contrase&ntilde;a:',
'login_preferez_refuser' => '<b>Si prefieres rechazar las "cookies"</b>, otro m&eacute;todo de conexi&oacute;n (menos seguro) est&aacute; a tu disposici&oacute;n:',
'login_recharger' => 'actualizar esta p&aacute;gina',
'login_rester_identifie' => 'Quedar identificado unos d&iacute;as',
'login_retour_public' => 'Volver al sitio p&uacute;blico',
'login_retour_site' => 'Volver al sitio p&uacute;blico',
'login_retoursitepublic' => 'volver&nbsp;al&nbsp;sitio&nbsp;p&uacute;blico',
'login_sans_cookiie' => 'Identificaci&oacute;n sin "cookie"',
'login_securise' => 'Conexi&oacute;n segura',
'login_sinscrire' => 'inscribirse',
'login_test_navigateur' => 'prueba de navegador/reconexi&oacute;n',
'login_verifiez_navigateur' => '(No obstante, comprueba que tu navegador no memoriz&oacute; tu contrase&ntilde;a...)',

// M
'masquer_colonne' => 'Ocultar esta columna',
'masquer_trad' => 'Ocultar las traducciones',
'module_fichiers_langues' => 'Archivos de idioma',

// N
'navigateur_pas_redirige' => 'Si tu navegador no te redirige automaticamente, pincha aqu&iacute; para continuar.',
'numero' => 'N&uacute;mero',

// O
'occurence' => 'Ocurrencia',
'onglet_affacer_base' => 'Borrar la base',
'onglet_auteur' => 'La autor/a',
'onglet_contenu_site' => 'Contenido del sitio',
'onglet_evolution_visite_mod' => 'Evoluci&oacute;n',
'onglet_fonctions_avances' => 'Funciones avanzadas',
'onglet_informations_personnelles' => 'Informaciones personales',
'onglet_interactivite' => 'Interactividad',
'onglet_messagerie' => 'Mensajer&iacute;a',
'onglet_messages_internes' => 'Mensajes internos',
'onglet_messages_publics' => 'Mensajes p&uacute;blicos',
'onglet_messages_vide' => 'Mensajes sin texto',
'onglet_origine_visites' => 'Origen de las visitas',
'onglet_repartition_debut' => 'desde el principio',
'onglet_repartition_lang' => 'Distribuci&oacute;n por idiomas',
'onglet_repartition_rubrique' => 'Reparto por secciones',
'onglet_save_restaur_base' => 'Copia de respaldo y restauraci&oacute;n de la base',
'onglet_vider_cache' => 'Vaciar la cach&eacute;',
'ortho_trop_de_fautes2' => 'Comienza por corregir las faltas m&aacute;s evidentes y vuelve a intentarlo.',

// P
'pass_choix_pass' => 'Elije tu nueva contrase&ntilde;a:',
'pass_erreur' => 'Error',
'pass_erreur_acces_refuse' => '<b>Error:</b> ya no tienes acceso a este sitio.',
'pass_erreur_code_inconnu' => '<b>Error:</b> este c&oacute;digo no corresponde a ning&uacute;n visitante que tenga acceso a este sitio.',
'pass_erreur_non_enregistre' => '<b>Error:</b> la direcci&oacute;n <tt>@email_oubli@</tt> no est&aacute; registrada en este sitio.',
'pass_erreur_non_valide' => '<b>Error:</b> esta direcci&oacute;n <tt>@email_oubli@</tt> no es v&aacute;lida.',
'pass_erreur_probleme_technique' => '<b>Error:</b> por un problema t&eacute;cnico, el mensaje no ha podido ser enviado.',
'pass_espace_prive_bla' => 'El espacio privado de este sitio est&aacute; abierto, mediante una inscripci&oacute;n. Una vez registrado/a, puedes consultar los art&iacute;culos en curso de redacci&oacute;n, proponer art&iacute;culos y participar en todos los foros.',
'pass_forum_bla' => 'Pediste intervenir en un foro reservado a las personas registradas.',
'pass_indiquez_cidessous' => 'Indica a continuaci&oacute;n la direcci&oacute;n de correo electr&oacute;nico bajo la cual te has registrado anteriormente. Recibir&aacute;s un mensaje indicando el proceso a seguir para recuperar tu acceso.',
'pass_mail_passcookie' => '(esto es un mensaje autom&aacute;tico)

Para recuperar tu acceso al sitio
@nom_site_spip@ (@adresse_site@)

Ir a la siguiente direcci&oacute;n:

    @sendcookie@

Ah&iacute; podr&aacute;s poner una nueva contrase&ntilde;a y
volver a conectarte al sitio.

',
'pass_mot_oublie' => 'Contrase&ntilde;a olvidada',
'pass_nouveau_enregistre' => 'Tu nueva contrase&ntilde;a fue registrada.',
'pass_nouveau_pass' => 'Nueva contrase&ntilde;a',
'pass_ok' => 'OK',
'pass_oubli_mot' => 'Contrase&ntilde;a olvidada',
'pass_quitter_fenetre' => 'Abandonar esta ventana',
'pass_rappel_login' => 'Recuerda: tu identificador (login) es &laquo;@login@&raquo;.',
'pass_recevoir_mail' => 'Recibir&aacute;s un mensaje de correo electr&oacute;nico indicando como recuperar tu acceso al sitio.',
'pass_retour_public' => 'Volver al sitio p&uacute;blico',
'pass_rien_a_faire_ici' => 'Nada que hacer aqu&iacute;.',
'pass_vousinscrire' => 'Inscribirse en este sitio',
'precedent' => 'precedente',
'previsualisation' => 'Previsualizaci&oacute;n',
'previsualiser' => 'Previsualizar',

// R
'retour' => 'Volver',

// S
'spip_conforme_dtd' => 'SPIP considera este documento como conforme a su DOCTYPE:',
'squelette' => 'esqueleto',
'squelette_inclus_ligne' => 'esqueleto inclu&iacute;do, l&iacute;nea',
'squelette_ligne' => 'esqueleto, l&iacute;nea',
'stats_visites_et_popularite' => '@visites@ visitas; popularidad: @popularite@',
'suivant' => 'siguiente',

// T
'taille_ko' => '@taille@&nbsp;KB',
'taille_mo' => '@taille@&nbsp;MB',
'taille_octets' => '@taille@&nbsp;bytes',
'texte_actualite_site_1' => 'Una vez que te hayas familiarizado con la interfaz, pincha en &laquo;',
'texte_actualite_site_2' => 'interfaz completa',
'texte_actualite_site_3' => '&raquo; que tiene a&uacute;n m&aacute;s posibilidades.',
'texte_creation_automatique_vignette' => 'Este sitio permite la creaci&oacute;n autom&aacute;tica de iconos en los siguientes formatos: @gd_formats@. Las im&aacute;genes que instales con este formulario tendr&aacute;n iconos de @taille_preview@ p&iacute;xeles.',
'texte_documents_associes' => 'Los documentos siguientes est&aacute;n asociados al art&iacute;culo, pero no han sido insertados directamente. Seg&uacute;n el formato del sitio p&uacute;blico, pueden aparecer como documentos adjuntos.',
'texte_erreur_mise_niveau_base' => 'Error de la base de datos en el curso la la actualizaci&oacute;n.
La imagen <b>@fichier@</b> no ha pasado (art&iacute;culo @id_article@).
Tome nota de esta referencia, reintente la actualizaci&oacute;n y verifique que las im&aacute;genes aparecen en los art&iacute;culos.',
'texte_erreur_visiteur' => 'Has intentado entrar al espacio privado con un identificador que no lo permite.',
'texte_inc_auth_1' => 'Est&aacute;s identificado con el
 login  <b>@auth_login@</b>, pero &eacute;ste (ya) no existe en la base.
Intenta',
'texte_inc_auth_2' => 'reconectarte',
'texte_inc_auth_3' => ', eventualmente despu&eacute;s de cerrar y reiniciar tu navegador.',
'texte_inc_config' => 'Las modificaciones efectuadas en estas p&aacute;ginas influyen notablemente en el funcionamiento de tu sitio. Te recomendamos no intervenir mientras no est&eacute;s familiarizad@ con el funcionamiento del sistema SPIP. <br /><br /><b>M&aacute;s &aacute;mpliamente, se recomienda vivamente dejar la gesti&oacute;n de estas p&aacute;ginas al o a la webmestre principal del sitio.</b>',
'texte_inc_meta_1' => 'El sistema encontr&oacute; un error de escritura del archivo <code>@fichier@</code>. Como administrador(a) del sitio, procede',
'texte_inc_meta_2' => 'a verificar los derechos de escritura',
'texte_inc_meta_3' => 'del directorio <code>@repertoire@</code>.',
'texte_statut_en_cours_redaction' => 'En curso de redacci&oacute;n',
'texte_statut_poubelle' => 'A la papelera',
'texte_statut_propose_evaluation' => 'propuesto a la evaluaci&oacute;n',
'texte_statut_publie' => 'Publicado',
'texte_statut_refuse' => 'Rechazado',
'titre_ajouter_mot_cle' => 'A&ntilde;adir una palabra clave',
'titre_breve_proposee' => 'Breve propuesta',
'titre_breve_publiee' => 'Breve publicada',
'titre_breve_refusee' => 'Breve rechazada',
'titre_cadre_raccourcis' => 'Atajos...',
'titre_changer_couleur_interface' => 'Cambiar el color de la interfaz',
'titre_forum' => 'Foro interno',
'titre_image_admin_article' => 'Puedes administrar este art&iacute;culo',
'titre_image_administrateur' => 'Administrador/a',
'titre_image_aide' => 'Ayuda sobre este elemento',
'titre_image_auteur_supprime' => 'Autor suprimido',
'titre_image_redacteur' => 'Redactor o redactora sin acceso',
'titre_image_redacteur_02' => 'Redactor o redactora',
'titre_image_visiteur' => 'Visitante',
'titre_joindre_document' => 'A&ntilde;adir un documento',
'titre_liens_entrants' => 'Los enlaces entrantes ',
'titre_mots_cles' => 'Palabras clave',
'titre_probleme_technique' => 'Atenci&oacute;n: una problema t&eacute;cnico (servidor SQL) impide el acceso a esta parte del sitio. Se agradece su comprensi&oacute;n.',
'titre_publier_document' => 'PUBLICAR UN DOCUMENTO EN ESTA SECCION',
'titre_signatures_attente' => 'Firmas esperando validaci&oacute;n',
'titre_signatures_confirmees' => 'Firmas confirmadas',
'titre_statistiques' => 'Estad&iacute;sticas del sitio',
'titre_titre_document' => 'T&iacute;tulo del documento',
'todo' => 'a continuaci&oacute;n',
'trad_reference' => '(art&iacute;culo de referencia)',

// Z
'zbug_balise_b_aval' => ': baliza de bucle B m&aacute;s adelante',
'zbug_balise_inexistante' => 'Baliza @balise@  mal declarada para @from@',
'zbug_balise_sans_argument' => 'Falta un argumento en la baliza @balise@',
'zbug_boucle' => 'bucle',
'zbug_boucle_recursive_undef' => 'Bucle recursivo no defindo&nbsp;: @nom@',
'zbug_calcul' => 'c&aacute;lculo',
'zbug_champ_hors_boucle' => 'Campo @champ@ fuera de bucle',
'zbug_champ_hors_motif' => 'El campo @champ@ est&aacute; fuera de contexto @motif@',
'zbug_code' => 'c&oacute;digo',
'zbug_critere_inconnu' => 'Criterio @critere@ desconocido ',
'zbug_distant_interdit' => 'Acceso externo prohibido',
'zbug_doublon_table_sans_cle_primaire' => 'Doublons en una tabla sin clave primaria simple',
'zbug_doublon_table_sans_index' => 'Doublons en una tabla sin &iacute;ndice',
'zbug_erreur_boucle_double' => 'Doble definici&oacute;n del bucle @id@',
'zbug_erreur_boucle_fermant' => 'Bucle @id@ sin baliza de cierre',
'zbug_erreur_boucle_syntaxe' => 'Sintaxis del bucle @id@ incorrecta',
'zbug_erreur_compilation' => 'Error de compilaci&oacute;n',
'zbug_erreur_execution_page' => 'Error de ejecuci&oacute;n',
'zbug_erreur_filtre' => 'Error: filtro @filtre@ no definido',
'zbug_erreur_meme_parent' => 'El criterio {meme_parent} s&oacute;lo se aplica a los  bucles (FORUMS) o (RUBRIQUES)',
'zbug_erreur_squelette' => 'Error(es) en el esqueleto',
'zbug_hors_compilation' => 'Sin compilaci&oacute;n',
'zbug_info_erreur_squelette' => 'Error en el sitio',
'zbug_inversion_ordre_inexistant' => 'Inversi&oacute;n de un orden inexistente',
'zbug_pagination_sans_critere' => 'Baliza #PAGINATION sin criterio {pagination} o empleado en un bucle recursivo',
'zbug_parametres_inclus_incorrects' => 'Par&aacute;metro de inclusi&oacute;n incorrecto: @param@',
'zbug_profile' => 'Duraci&oacute;n del c&aacute;lculo: @time@',
'zbug_resultat' => 'resultado',
'zbug_serveur_indefini' => 'Servidor SQL indefinido',
'zbug_statistiques' => 'Estad&iacute;stica de las consultas SQL ordenadas por duraci&oacute;n',
'zbug_table_inconnue' => 'Tabla SQL &laquo;@table@&raquo; desconocida',
'zxml_connus_attributs' => 'atributos conocidos',
'zxml_de' => 'de',
'zxml_inconnu_attribut' => 'atributos desconocidos',
'zxml_inconnu_balise' => 'baliza desconocida',
'zxml_inconnu_entite' => 'entidad desconocida',
'zxml_inconnu_id' => 'ID desconocido',
'zxml_mais_de' => 'pero de',
'zxml_non_conforme' => 'no es conforme por el motivo',
'zxml_non_fils' => 'no es hijo de ',
'zxml_nonvide_balise' => 'baliza no vac&iacute;a',
'zxml_obligatoire_attribut' => 'atributo obligatorio pero ausente en',
'zxml_succession_fils_incorrecte' => 'succesi&oacute;n de hijos incorrecta',
'zxml_survoler' => 'pasar por aqu&iacute; para ver los correctos',
'zxml_valeur_attribut' => 'valor del atributo',
'zxml_vide_balise' => 'baliza vac&iacute;a',
'zxml_vu' => 'visto antes'
);

?>
